#' @title gse1397
#' `ExpressionSet` for gse1397 dataset
#' @description
#' Normalized dataset GSE1397   
#' @details
#' \describe{
#' \item{gse1397}{Normalized gene expression data gse1397.
#' A quantile normalization has been applied using the function
#' limma::normalizeBetweenArrays. The fData slot contains the correspondences
#' between PROBEID, ENTREZID and ENSEMBL.}
#' }
#' 
#' @source
#' GEO  
#' \url{http://www.ncbi.nlm.nih.gov/geo/query/acc.cgi?acc=GSE1397}
#' The transformations from the original data can be found at
#' \url{http://www.uv.es/ayala/docencia/tami/CaseStudies/gse1397.html}
#' 
#' @docType data
#' @keywords datasets
#' @format 
#' \describe{
#' \item{gse1397}{ExpressionSet}
#' }
#' @name gse1397
NULL

#' @title gse1397ed
#' `ExpressionData` for gse1397 dataset
#' @description
#' `ExpressionData` for gse1397 dataset produced from tamidata::gse1397
#' @docType data
#' @keywords datasets
#' @name gse1397ed
NULL


#' @title gse1397.gsc
#' 
#' @description
#' Gene sets produced from the original dataset GSE1397   
#' @details
#' \describe{
#' \item{gse1397.gsc}{Gene set collection from gse1397 using Gene Ontology}
#' }
#' 
#' @source
#' GEO  
#' \url{http://www.ncbi.nlm.nih.gov/geo/query/acc.cgi?acc=GSE1397}
#' 
#' 
#' @examples
#' data(gse1397.gsc)
#' @docType data
#' @keywords datasets
#' @format 
#' \describe{
#' \item{gse1397.gsc}{GeneSetCollection}
#' }
#' @name gse1397.gsc
NULL


#' @title gse20986
#' 
#' @description
#' 
#' Normalized gene expression data gse20986
#' A GC-RMA normalization has been applied using the function
#' \link[gcrma]{gcrma}
#'
#' @source
#' GEO  
#' \url{http://www.ncbi.nlm.nih.gov/geo/query/acc.cgi?acc=GSE20986}
#' 
#' @examples
#' data(gse20986raw) ## Original data
#' data(gse20986)    ## Normalized data
#' @docType data
#' @keywords datasets
#' @format Biobase::ExpressionSet 
#' @name gse20986
NULL

#' @title n06_expr.txt
#' 
#' @description
#' Expression data 
#'
#' @source
#' Neve RM, Chin K, Fridlyand J, Yeh J, Baehner F, Fevr T, Clark L, Bayani N, 
#' Coppe J, Tong F, Speed T, Spellman PT, Devries S, Lapuk A, Wang NJ, Kuo W-L, 
#' Stilwell JL, Pinkel D, Albertson DG, Waldman FM, McCormick F, Dickson RB, 
#' Johnson MD, Lippman M, Ethier S, Gazdar A, and Gray JW. (2006) 
#' A collection of breast cancer cell lines for the study of functionally 
#' distinct cancer subtypes.  Cancer Cell, 10:515-27
#' http://www.cell.com/cancer-cell/abstract/S1535-6108(06)00314-X
#' http://www.cell.com/cancer-cell/supplemental/S1535-6108(06)00314-X
#'
#' @examples
#' library(tamidata)
#' finput = system.file("extdata","n06_expr.txt",package="tamidata")
#' x = read.table(file = finput,header = TRUE,sep="\t")
#' head(x,n=1)
#' @docType data
#' @keywords datasets
#' @format Ascii 
#' @name n06_expr.txt
NULL

#' @title n06_gene_attributes.txt
#' 
#' @description
#' Expression data 
#'
#' @source
#' Neve RM, Chin K, Fridlyand J, Yeh J, Baehner F, Fevr T, Clark L, Bayani N, 
#' Coppe J, Tong F, Speed T, Spellman PT, Devries S, Lapuk A, Wang NJ, Kuo W-L, 
#' Stilwell JL, Pinkel D, Albertson DG, Waldman FM, McCormick F, Dickson RB, 
#' Johnson MD, Lippman M, Ethier S, Gazdar A, and Gray JW. (2006) 
#' A collection of breast cancer cell lines for the study of functionally 
#' distinct cancer subtypes.  Cancer Cell, 10:515-27
#' http://www.cell.com/cancer-cell/abstract/S1535-6108(06)00314-X
#' http://www.cell.com/cancer-cell/supplemental/S1535-6108(06)00314-X
#'
#' @examples
#' library(tamidata)
#' finput = system.file("extdata","n06_gene_attributes.txt",package="tamidata")
#' x = read.table(file = finput,header = TRUE,sep="\t")
#' head(x,n=1)
#' 
#' @docType data
#' @keywords datasets
#' @format Ascii 
#' @name n06_gene_attributes.txt
NULL

#' @title n06_sample_attributes.txt
#' 
#' @description
#' Expression data ' 
#'
#' @source
#' Neve RM, Chin K, Fridlyand J, Yeh J, Baehner F, Fevr T, Clark L, Bayani N, 
#' Coppe J, Tong F, Speed T, Spellman PT, Devries S, Lapuk A, Wang NJ, Kuo W-L, 
#' Stilwell JL, Pinkel D, Albertson DG, Waldman FM, McCormick F, Dickson RB, 
#' Johnson MD, Lippman M, Ethier S, Gazdar A, and Gray JW. (2006) 
#' A collection of breast cancer cell lines for the study of functionally 
#' distinct cancer subtypes.  Cancer Cell, 10:515-27
#' http://www.cell.com/cancer-cell/abstract/S1535-6108(06)00314-X
#' http://www.cell.com/cancer-cell/supplemental/S1535-6108(06)00314-X
#'
#' @examples
#' library(tamidata)
#' finput = system.file("extdata","n06_sample_attributes.txt",
#' package="tamidata")
#' x = read.table(file = finput,header = TRUE,sep="\t")
#' head(x,n=1)
#' 
#' @docType data
#' @keywords datasets
#' @format Ascii 
#' @name n06_sample_attributes.txt
NULL

#' @title gscSc
#' 
#' @description
#' Gene set collection using Gene Ontology for Sacaromice Cerevisiae
#' @examples
#' data(gscSc,package="tamidata")
#' ## The following code produce the data set
#' ## library(GSEABase)
#' ## library(org.Sc.sgd.db)
#' ## frame = toTable(org.Sc.sgdGO)
#' ## goframeData = data.frame(frame$go_id, frame$Evidence, frame$systematic_name)
#' ## goFrame = GOFrame(goframeData, organism = "Saccharomyces cerevisiae")
#' ## goAllFrame = GOAllFrame(goFrame)
#' ## gscSc = GeneSetCollection(goAllFrame, setType = GOCollection())
#' ## save(gscSc,file="gscSc.rda")
#' @docType data
#' @keywords datasets
#' @format  GSEABase::GeneSetCollection
#' @name gscSc
NULL


#' @title PRJNA297664
#' 
#' @description
#' Saccharomyces cerevisiae
#' Expression profiling by high throughput sequencing
#' Identification of the difference in transcriptome between wild-type and
#' SEC66 deletion mutant cells#' 
#' @source
#'  \url{http://www.ncbi.nlm.nih.gov/bioproject/297664}
#'  \url{http://www.ncbi.nlm.nih.gov/geo/query/acc.cgi?acc=GSE73681}
#' The procedure to produce the counts per gene from the original sra files
#' can be found at
#' \url{http://www.uv.es/ayala/docencia/tami/CaseStudies/PRJNA297664.html}
#' @examples
#' data(PRJNA297664,package="tamidata")
#' @docType data
#' @keywords datasets
#' @format SummarizedExperiment
#' 
#' @name PRJNA297664
NULL

#' @title PRJNA266927
#' 
#' @description
#' Expression profiling by high throughtput sequencing
#' 
#'
#' The procedure to produce the counts per gene from the original sra files
#' can be found at
#' \url{http://www.uv.es/ayala/docencia/tami/CaseStudies/PRJNA266927.html}
#'
#' @examples
#' data(PRJNA266927,package="tamidata")
#' @docType data
#' @keywords datasets
#' @format SummarizedExperiment 
#' @name PRJNA266927
NULL



#' @title gse21942
#' 
#' @description
#' Expression profiling by high throughput sequencing. 
#' These data where analyzed in Kemppinen AK, Kaprio J, Palotie A, Saarela J.
#' Systematic review of genome-wide expression studies in multiple sclerosis.
#' BMJ Open. 2011 Jul 18;1(1):e000053. doi: 10.1136/bmjopen-2011-000053.
#'
#' We have normalized the raw data using Robust Multiarray Average (RMA).
#' 
#' 
#' @source
#' \url{https://www.ebi.ac.uk/arrayexpress/experiments/E-GEOD-21942/}.
#' \url{http://www.uv.es/ayala/docencia/tami/CaseStudies/gse21942.html} proposes code
#' to download and analyze this data set. 
#'  
#'  
#' @examples
#' data(gse21942,package="tamidata")
#' @docType data
#' @keywords datasets
#' @format ExpressionSet
#' @name gse21942
NULL


#' geod24243
#' 
#' @description 
#' ExpressionSet \code{geod24243}  
#' 
#' @source
#' \url{http://www.ebi.ac.uk/arrayexpress/experiments/E-GEOD-24243/} and 
#' \url{https://www.ncbi.nlm.nih.gov/geo/query/acc.cgi?acc=GSE24243}.
#' The ExpressionSet can be obtained from the original raw dataset using
#' 
#' @examples 
#' data(geod24243,package="tamidata")
#' @docType data
#' @keywords datasets
#' @format ExpressionSet
#' @name geod24243
NULL

#' gse44456
#' @description 
#' ExpressionSet \code{gse44456}  
#' 
#' @examples 
#' data(gse44456,package="tamidata")
#' @docType data
#' @keywords datasets
#' @format ExpressionSet
#' @name gse44456
NULL

#' gse6647
#' @description 
#' ExpressionSet \code{gse6647}  
#' 
#' @examples 
#' data(gse6647,package="tamidata")
#' @docType data
#' @keywords datasets
#' @format ExpressionSet
#' @name gse6647
NULL


#' gse28619
#' @description 
#' ExpressionSet \code{gse28619}  
#' 
#' @examples 
#' data(gse28619,package="tamidata")
#' @docType data
#' @keywords datasets
#' @format ExpressionSet
#' @name gse28619
NULL


#' PRJNA297798
#' @description 
#' `RangedSummarizedExperiment` \code{PRJNA297798}  
#' 
#' @examples 
#' data(PRJNA297798,package="tamidata")
#' @docType data
#' @keywords datasets
#' @format `RangedSummarizedExperiment`
#' @name PRJNA297798
NULL


#' geod71810
#' @description 
#' ExpressionSet \code{geod71810}  
#' 
#' @examples 
#' data(geod71810,package="tamidata")
#' @docType data
#' @keywords datasets
#' @format ExpressionSet
#' @name geod71810
NULL

